Encoder

Trait Encoder 

pub trait Encoder<Item, B>
where B: IoBufMut,
{ type Error: From<Error>; // Required method fn encode(&mut self, item: Item, buf: &mut B) -> Result<(), Self::Error>; }
Available on crate feature io only.
Trait for types that encode values into bytes.

Required Associated Types

type Error: From<Error>

The error type that can be returned during encoding operations.

Required Methods

fn encode(&mut self, item: Item, buf: &mut B) -> Result<(), Self::Error>

Encodes an item into bytes.

The buf is guaranteed to have 0 initialized bytes (buf_len() == 0). If the function is returned successfully, all initialized bytes will be treated as valid content to be transmitted.

Implementors